==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/en/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "this qtr.",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"field-quarter-short-relative+1": "next qtr.",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "year",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"timeFormat-short": "h:mm a",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "this Tu",
	"field-tue-narrow-relative+1": "next Tu",
	"field-thu-short-relative+0": "this Thu.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "next Thu.",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-wed-narrow-relative+-1": "last W",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-second-short": "sec.",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Su",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "this Mon.",
	"field-sun-narrow-relative+1": "next Su",
	"field-mon-short-relative+1": "next Mon.",
	"field-second-relative+0": "now",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-month-short": "mo.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "M/d/y GGGGG",
	"field-day": "day",
	"field-year-relative+-1": "last year",
	"field-sat-short-relative+-1": "last Sat.",
	"field-hour-relative+0": "this hour",
	"dateFormatItem-yyyyMEd": "E, M/d/y GGGGG",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "last Sa",
	"field-second": "second",
	"dateFormat-long": "d MMMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "quarter",
	"field-week-short": "wk.",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"quarters-standAlone-wide": [
		"1st quarter",
		"2nd quarter",
		"3rd quarter",
		"4th quarter"
	],
	"field-tue-short-relative+0": "this Tue.",
	"field-tue-short-relative+1": "next Tue.",
	"field-month-short-relative+-1": "last mo.",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "month",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "am/pm",
	"field-sat-short-relative+0": "this Sat.",
	"field-sat-short-relative+1": "next Sat.",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d MMM y",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"AM"
	],
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-year-short": "yr.",
	"field-quarter-relative+-1": "last quarter",
	"dateFormatItem-yyyyMMMd": "MMM d, y G",
	"days-format-short": [
		"Su",
		"Mo",
		"Tu",
		"We",
		"Th",
		"Fr",
		"Sa"
	],
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-Md": "d MMM",
	"field-hour": "hour",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"dateFormat-full": "EEEE, d MMMM y",
	"field-month-relative+-1": "last month",
	"field-quarter-short": "qtr.",
	"field-sat-narrow-relative+0": "this Sa",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Sa",
	"field-fri-relative+1": "next Friday",
	"field-sun-short-relative+0": "this Sun.",
	"field-sun-short-relative+1": "next Sun.",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last qtr.",
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wed.",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormat-short": "d MMM y",
	"field-thu-short-relative+-1": "last Thu.",
	"days-standAlone-wide": [
		"Sunday",
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday"
	],
	"dateFormatItem-yyyyMMMEd": "E, MMM d, y G",
	"field-mon-narrow-relative+-1": "last M",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "last Th",
	"field-tue-narrow-relative+-1": "last Tu",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "this Wed.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "next Wed.",
	"field-sun-relative+-1": "last Sunday",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"field-weekday": "day of the week",
	"field-sat-relative+0": "this Saturday",
	"field-sat-relative+1": "next Saturday",
	"field-week-short-relative+0": "this wk.",
	"field-week-short-relative+1": "next wk.",
	"field-month-short-relative+0": "this mo.",
	"field-month-short-relative+1": "next mo.",
	"timeFormat-full": "h:mm:ss a zzzz",
	"dateFormatItem-MEd": "E, d MMM",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "this Th",
	"field-thu-narrow-relative+1": "next Th",
	"field-sun-narrow-relative+-1": "last Su",
	"field-mon-short-relative+-1": "last Mon.",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"field-fri-short-relative+-1": "last Fri.",
	"field-thu-relative+-1": "last Thursday",
	"dateFormatItem-yMd": "d MMM y",
	"field-week": "week",
	"quarters-format-wide": [
		"1st quarter",
		"2nd quarter",
		"3rd quarter",
		"4th quarter"
	],
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "this W",
	"field-wed-narrow-relative+1": "next W",
	"field-year-short-relative+0": "this yr.",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "next yr.",
	"field-fri-short-relative+0": "this Fri.",
	"field-fri-short-relative+1": "next Fri.",
	"days-standAlone-short": [
		"Su",
		"Mo",
		"Tu",
		"We",
		"Th",
		"Fr",
		"Sa"
	],
	"field-week-short-relative+-1": "last wk.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "hr.",
	"field-fri-narrow-relative+-1": "last F",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"field-tue-short-relative+-1": "last Tue.",
	"dateFormatItem-yQQQ": "QQQ y",
	"days-format-wide": [
		"Sunday",
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday"
	],
	"field-mon-narrow-relative+0": "this M",
	"field-mon-narrow-relative+1": "next M",
	"field-year-short-relative+-1": "last yr.",
	"field-zone": "time zone",
	"dateFormatItem-yM": "MMM y",
	"dateFormatItem-yMMMM": "MMMM y",
	"dateFormatItem-MMMEd": "E, d MMM",
	"dateFormatItem-yMEd": "E, d MMM y",
	"field-sun-short-relative+-1": "last Sun.",
	"field-day-relative+-1": "yesterday",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "day",
	"field-era": "era",
	"field-fri-narrow-relative+0": "this F",
	"field-fri-narrow-relative+1": "next F"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/en/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "this qtr.",
	"dateTimeFormats-appendItem-Year": "{0} {1}",
	"field-quarter-short-relative+1": "next qtr.",
	"field-tue-relative+-1": "last Tuesday",
	"field-year": "year",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"timeFormat-short": "h:mm a",
	"field-minute": "minute",
	"field-tue-narrow-relative+0": "this Tu",
	"field-tue-narrow-relative+1": "next Tu",
	"field-thu-short-relative+0": "this Thu.",
	"dateTimeFormat-short": "{1}, {0}",
	"field-thu-short-relative+1": "next Thu.",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-wed-narrow-relative+-1": "last W",
	"field-era-short": "era",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-weekdayOfMonth": "weekday of the month",
	"field-second-short": "sec.",
	"dayPeriods-format-narrow-am": "a",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "this week",
	"field-month-relative+0": "this month",
	"field-week-relative+1": "next week",
	"field-month-relative+1": "next month",
	"field-sun-narrow-relative+0": "this Su",
	"timeFormat-medium": "h:mm:ss a",
	"field-mon-short-relative+0": "this Mon.",
	"field-sun-narrow-relative+1": "next Su",
	"field-mon-short-relative+1": "next Mon.",
	"field-second-relative+0": "now",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "week of month",
	"field-month-short": "mo.",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"dateFormatItem-yyyyMd": "M/d/y GGGGG",
	"field-day": "day",
	"field-dayOfYear-short": "day of yr.",
	"field-year-relative+-1": "last year",
	"field-sat-short-relative+-1": "last Sat.",
	"field-hour-relative+0": "this hour",
	"dateFormatItem-yyyyMEd": "E, M/d/y GGGGG",
	"field-second-short-relative+0": "now",
	"field-wed-relative+-1": "last Wednesday",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-sat-narrow-relative+-1": "last Sa",
	"field-second": "second",
	"dateFormat-long": "d MMMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-quarter": "quarter",
	"field-week-short": "wk.",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"quarters-standAlone-wide": [
		"1st quarter",
		"2nd quarter",
		"3rd quarter",
		"4th quarter"
	],
	"field-tue-short-relative+0": "this Tue.",
	"field-tue-short-relative+1": "next Tue.",
	"field-month-short-relative+-1": "last mo.",
	"field-mon-relative+-1": "last Monday",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-month": "month",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min.",
	"field-dayperiod": "am/pm",
	"field-sat-short-relative+0": "this Sat.",
	"field-sat-short-relative+1": "next Sat.",
	"dayPeriods-format-narrow-pm": "p",
	"dateFormat-medium": "d MMM y",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"eraAbbr": [
		"AM"
	],
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-mon-relative+0": "this Monday",
	"field-mon-relative+1": "next Monday",
	"field-year-short": "yr.",
	"field-quarter-relative+-1": "last quarter",
	"dateFormatItem-yyyyMMMd": "MMM d, y G",
	"days-format-short": [
		"Su",
		"Mo",
		"Tu",
		"We",
		"Th",
		"Fr",
		"Sa"
	],
	"field-dayOfYear": "day of year",
	"field-sat-relative+-1": "last Saturday",
	"dateTimeFormat-long": "{1} 'at' {0}",
	"dateFormatItem-Md": "d MMM",
	"field-hour": "hour",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"dateFormat-full": "EEEE, d MMMM y",
	"field-month-relative+-1": "last month",
	"field-quarter-short": "qtr.",
	"field-sat-narrow-relative+0": "this Sa",
	"field-fri-relative+0": "this Friday",
	"field-sat-narrow-relative+1": "next Sa",
	"field-fri-relative+1": "next Friday",
	"field-sun-short-relative+0": "this Sun.",
	"field-sun-short-relative+1": "next Sun.",
	"field-week-relative+-1": "last week",
	"field-quarter-short-relative+-1": "last qtr.",
	"field-quarter-relative+0": "this quarter",
	"field-minute-relative+0": "this minute",
	"timeFormat-long": "h:mm:ss a z",
	"field-quarter-relative+1": "next quarter",
	"field-wed-short-relative+-1": "last Wed.",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormat-short": "d MMM y",
	"field-thu-short-relative+-1": "last Thu.",
	"days-standAlone-wide": [
		"Sunday",
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday"
	],
	"dateFormatItem-yyyyMMMEd": "E, MMM d, y G",
	"field-mon-narrow-relative+-1": "last M",
	"dateTimeFormats-appendItem-Era": "{0} {1}",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-thu-narrow-relative+-1": "last Th",
	"field-tue-narrow-relative+-1": "last Tu",
	"field-weekOfMonth-short": "wk. of mo.",
	"dateFormatItem-yyyy": "y G",
	"field-wed-short-relative+0": "this Wed.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "next Wed.",
	"field-sun-relative+-1": "last Sunday",
	"dateTimeFormat-full": "{1} 'at' {0}",
	"field-weekday": "day of the week",
	"field-sat-relative+0": "this Saturday",
	"field-sat-relative+1": "next Saturday",
	"field-week-short-relative+0": "this wk.",
	"field-week-short-relative+1": "next wk.",
	"field-month-short-relative+0": "this mo.",
	"field-month-short-relative+1": "next mo.",
	"field-weekdayOfMonth-short": "wkday. of mo.",
	"timeFormat-full": "h:mm:ss a zzzz",
	"dateFormatItem-MEd": "E, d MMM",
	"dateFormatItem-y": "y",
	"field-thu-narrow-relative+0": "this Th",
	"field-thu-narrow-relative+1": "next Th",
	"field-sun-narrow-relative+-1": "last Su",
	"field-mon-short-relative+-1": "last Mon.",
	"field-thu-relative+0": "this Thursday",
	"field-thu-relative+1": "next Thursday",
	"field-fri-short-relative+-1": "last Fri.",
	"field-thu-relative+-1": "last Thursday",
	"dateFormatItem-yMd": "d MMM y",
	"field-week": "week",
	"quarters-format-wide": [
		"1st quarter",
		"2nd quarter",
		"3rd quarter",
		"4th quarter"
	],
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "this W",
	"field-wed-narrow-relative+1": "next W",
	"field-year-short-relative+0": "this yr.",
	"field-dayperiod-short": "am/pm",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"field-year-short-relative+1": "next yr.",
	"field-fri-short-relative+0": "this Fri.",
	"field-fri-short-relative+1": "next Fri.",
	"days-standAlone-short": [
		"Su",
		"Mo",
		"Tu",
		"We",
		"Th",
		"Fr",
		"Sa"
	],
	"field-week-short-relative+-1": "last wk.",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "hr.",
	"field-zone-short": "zone",
	"field-fri-narrow-relative+-1": "last F",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-fri-relative+-1": "last Friday",
	"field-tue-short-relative+-1": "last Tue.",
	"dateFormatItem-yQQQ": "QQQ y",
	"days-format-wide": [
		"Sunday",
		"Monday",
		"Tuesday",
		"Wednesday",
		"Thursday",
		"Friday",
		"Saturday"
	],
	"field-mon-narrow-relative+0": "this M",
	"field-mon-narrow-relative+1": "next M",
	"field-year-short-relative+-1": "last yr.",
	"dateFormatItem-yM": "MMM y",
	"field-zone": "time zone",
	"dateFormatItem-yMMMM": "MMMM y",
	"dateFormatItem-MMMEd": "E, d MMM",
	"dateFormatItem-yMEd": "E, d MMM y",
	"field-sun-short-relative+-1": "last Sun.",
	"field-day-relative+-1": "yesterday",
	"field-weekday-short": "day of wk.",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateFormatItem-yMMMd": "d MMM y",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "day",
	"field-era": "era",
	"field-fri-narrow-relative+0": "this F",
	"field-fri-narrow-relative+1": "next F"
}
//end v1.x content
);
